@@ -14,11 +14,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import csv
 from operator import attrgetter
 from tempfile import NamedTemporaryFile
-from typing import TYPE_CHECKING, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.ads.hooks.ads import GoogleAdsHook
@@ -43,23 +44,14 @@ class GoogleAdsToGcsOperator(BaseOperator):
         :ref:`howto/operator:GoogleAdsToGcsOperator`
 
     :param client_ids: Google Ads client IDs to query
-    :type client_ids: List[str]
     :param query: Google Ads Query Language API query
-    :type query: str
     :param attributes: List of Google Ads Row attributes to extract
-    :type attributes: List[str]
     :param bucket: The GCS bucket to upload to
-    :type bucket: str
     :param obj: GCS path to save the object. Must be the full file path (ex. `path/to/file.txt`)
-    :type obj: str
     :param gcp_conn_id: Airflow Google Cloud connection ID
-    :type gcp_conn_id: str
     :param google_ads_conn_id: Airflow Google Ads connection ID
-    :type google_ads_conn_id: str
     :param page_size: The number of results per API page request. Max 10,000
-    :type page_size: int
     :param gzip: Option to compress local file or file data for upload
-    :type gzip: bool
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -68,9 +60,7 @@ class GoogleAdsToGcsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     :param api_version: Optional Google Ads API version to use.
-    :type api_version: Optional[str]
     """
 
     template_fields: Sequence[str] = (
@@ -85,17 +75,17 @@ class GoogleAdsToGcsOperator(BaseOperator):
     def __init__(
         self,
         *,
-        client_ids: List[str],
+        client_ids: list[str],
         query: str,
-        attributes: List[str],
+        attributes: list[str],
         bucket: str,
         obj: str,
         gcp_conn_id: str = "google_cloud_default",
         google_ads_conn_id: str = "google_ads_default",
         page_size: int = 10000,
         gzip: bool = False,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
-        api_version: Optional[str] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        api_version: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -111,7 +101,7 @@ class GoogleAdsToGcsOperator(BaseOperator):
         self.impersonation_chain = impersonation_chain
         self.api_version = api_version
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         service = GoogleAdsHook(
             gcp_conn_id=self.gcp_conn_id,
             google_ads_conn_id=self.google_ads_conn_id,
