@@ -19,6 +19,7 @@
 from __future__ import annotations
 
 import enum
+import warnings
 from typing import Sequence
 
 from google.cloud.bigtable import Client
@@ -46,6 +47,10 @@ class BigtableHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
