@@ -15,11 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains a Google Cloud Dataproc Metastore hook."""
+from __future__ import annotations
 
-from typing import Any, Dict, Optional, Sequence, Tuple, Union
+from typing import Any, Sequence
 
+from google.api_core.client_options import ClientOptions
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.operation import Operation
 from google.api_core.retry import Retry
 from google.cloud.metastore_v1 import DataprocMetastoreClient
@@ -37,13 +39,13 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
     def get_dataproc_metastore_client(self) -> DataprocMetastoreClient:
         """Returns DataprocMetastoreClient."""
-        client_options = {'api_endpoint': 'metastore.googleapis.com:443'}
+        client_options = ClientOptions(api_endpoint="metastore.googleapis.com:443")
 
         return DataprocMetastoreClient(
-            credentials=self._get_credentials(), client_info=CLIENT_INFO, client_options=client_options
+            credentials=self.get_credentials(), client_info=CLIENT_INFO, client_options=client_options
         )
 
-    def wait_for_operation(self, timeout: Optional[float], operation: Operation):
+    def wait_for_operation(self, timeout: float | None, operation: Operation):
         """Waits for long-lasting operation to complete."""
         try:
             return operation.result(timeout=timeout)
@@ -57,12 +59,12 @@ class DataprocMetastoreHook(GoogleBaseHook):
         project_id: str,
         region: str,
         service_id: str,
-        backup: Union[Dict[Any, Any], Backup],
+        backup: dict[Any, Any] | Backup,
         backup_id: str,
-        request_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        request_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Creates a new backup in a given project and location.
@@ -92,15 +94,15 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        parent = f'projects/{project_id}/locations/{region}/services/{service_id}'
+        parent = f"projects/{project_id}/locations/{region}/services/{service_id}"
 
         client = self.get_dataproc_metastore_client()
         result = client.create_backup(
             request={
-                'parent': parent,
-                'backup': backup,
-                'backup_id': backup_id,
-                'request_id': request_id,
+                "parent": parent,
+                "backup": backup,
+                "backup_id": backup_id,
+                "request_id": request_id,
             },
             retry=retry,
             timeout=timeout,
@@ -114,12 +116,12 @@ class DataprocMetastoreHook(GoogleBaseHook):
         project_id: str,
         region: str,
         service_id: str,
-        metadata_import: MetadataImport,
+        metadata_import: dict | MetadataImport,
         metadata_import_id: str,
-        request_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        request_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Creates a new MetadataImport in a given project and location.
@@ -150,15 +152,15 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        parent = f'projects/{project_id}/locations/{region}/services/{service_id}'
+        parent = f"projects/{project_id}/locations/{region}/services/{service_id}"
 
         client = self.get_dataproc_metastore_client()
         result = client.create_metadata_import(
             request={
-                'parent': parent,
-                'metadata_import': metadata_import,
-                'metadata_import_id': metadata_import_id,
-                'request_id': request_id,
+                "parent": parent,
+                "metadata_import": metadata_import,
+                "metadata_import_id": metadata_import_id,
+                "request_id": request_id,
             },
             retry=retry,
             timeout=timeout,
@@ -171,12 +173,12 @@ class DataprocMetastoreHook(GoogleBaseHook):
         self,
         region: str,
         project_id: str,
-        service: Union[Dict, Service],
+        service: dict | Service,
         service_id: str,
-        request_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        request_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Creates a metastore service in a project and location.
@@ -200,15 +202,15 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        parent = f'projects/{project_id}/locations/{region}'
+        parent = f"projects/{project_id}/locations/{region}"
 
         client = self.get_dataproc_metastore_client()
         result = client.create_service(
             request={
-                'parent': parent,
-                'service_id': service_id,
-                'service': service if service else {},
-                'request_id': request_id,
+                "parent": parent,
+                "service_id": service_id,
+                "service": service if service else {},
+                "request_id": request_id,
             },
             retry=retry,
             timeout=timeout,
@@ -223,10 +225,10 @@ class DataprocMetastoreHook(GoogleBaseHook):
         region: str,
         service_id: str,
         backup_id: str,
-        request_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        request_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Deletes a single backup.
@@ -251,13 +253,13 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        name = f'projects/{project_id}/locations/{region}/services/{service_id}/backups/{backup_id}'
+        name = f"projects/{project_id}/locations/{region}/services/{service_id}/backups/{backup_id}"
 
         client = self.get_dataproc_metastore_client()
         result = client.delete_backup(
             request={
-                'name': name,
-                'request_id': request_id,
+                "name": name,
+                "request_id": request_id,
             },
             retry=retry,
             timeout=timeout,
@@ -271,10 +273,10 @@ class DataprocMetastoreHook(GoogleBaseHook):
         project_id: str,
         region: str,
         service_id: str,
-        request_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        request_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Deletes a single service.
@@ -293,13 +295,13 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        name = f'projects/{project_id}/locations/{region}/services/{service_id}'
+        name = f"projects/{project_id}/locations/{region}/services/{service_id}"
 
         client = self.get_dataproc_metastore_client()
         result = client.delete_service(
             request={
-                'name': name,
-                'request_id': request_id,
+                "name": name,
+                "request_id": request_id,
             },
             retry=retry,
             timeout=timeout,
@@ -314,11 +316,11 @@ class DataprocMetastoreHook(GoogleBaseHook):
         project_id: str,
         region: str,
         service_id: str,
-        request_id: Optional[str] = None,
-        database_dump_type: Optional[DatabaseDumpSpec] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        request_id: str | None = None,
+        database_dump_type: DatabaseDumpSpec | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Exports metadata from a service.
@@ -343,15 +345,15 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        service = f'projects/{project_id}/locations/{region}/services/{service_id}'
+        service = f"projects/{project_id}/locations/{region}/services/{service_id}"
 
         client = self.get_dataproc_metastore_client()
         result = client.export_metadata(
             request={
-                'destination_gcs_folder': destination_gcs_folder,
-                'service': service,
-                'request_id': request_id,
-                'database_dump_type': database_dump_type,
+                "destination_gcs_folder": destination_gcs_folder,
+                "service": service,
+                "request_id": request_id,
+                "database_dump_type": database_dump_type,
             },
             retry=retry,
             timeout=timeout,
@@ -365,9 +367,9 @@ class DataprocMetastoreHook(GoogleBaseHook):
         project_id: str,
         region: str,
         service_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Gets the details of a single service.
@@ -385,12 +387,12 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        name = f'projects/{project_id}/locations/{region}/services/{service_id}'
+        name = f"projects/{project_id}/locations/{region}/services/{service_id}"
 
         client = self.get_dataproc_metastore_client()
         result = client.get_service(
             request={
-                'name': name,
+                "name": name,
             },
             retry=retry,
             timeout=timeout,
@@ -405,9 +407,9 @@ class DataprocMetastoreHook(GoogleBaseHook):
         region: str,
         service_id: str,
         backup_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Backup:
         """
         Get backup from a service.
@@ -426,11 +428,11 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        backup = f'projects/{project_id}/locations/{region}/services/{service_id}/backups/{backup_id}'
+        backup = f"projects/{project_id}/locations/{region}/services/{service_id}/backups/{backup_id}"
         client = self.get_dataproc_metastore_client()
         result = client.get_backup(
             request={
-                'name': backup,
+                "name": backup,
             },
             retry=retry,
             timeout=timeout,
@@ -444,13 +446,13 @@ class DataprocMetastoreHook(GoogleBaseHook):
         project_id: str,
         region: str,
         service_id: str,
-        page_size: Optional[int] = None,
-        page_token: Optional[str] = None,
-        filter: Optional[str] = None,
-        order_by: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        page_size: int | None = None,
+        page_token: str | None = None,
+        filter: str | None = None,
+        order_by: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Lists backups in a service.
@@ -487,16 +489,16 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        parent = f'projects/{project_id}/locations/{region}/services/{service_id}/backups'
+        parent = f"projects/{project_id}/locations/{region}/services/{service_id}/backups"
 
         client = self.get_dataproc_metastore_client()
         result = client.list_backups(
             request={
-                'parent': parent,
-                'page_size': page_size,
-                'page_token': page_token,
-                'filter': filter,
-                'order_by': order_by,
+                "parent": parent,
+                "page_size": page_size,
+                "page_token": page_token,
+                "filter": filter,
+                "order_by": order_by,
             },
             retry=retry,
             timeout=timeout,
@@ -514,11 +516,11 @@ class DataprocMetastoreHook(GoogleBaseHook):
         backup_region: str,
         backup_service_id: str,
         backup_id: str,
-        restore_type: Optional[Restore] = None,
-        request_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        restore_type: Restore | None = None,
+        request_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Restores a service from a backup.
@@ -548,19 +550,19 @@ class DataprocMetastoreHook(GoogleBaseHook):
         :param timeout: The timeout for this request.
         :param metadata: Strings which should be sent along with the request as metadata.
         """
-        service = f'projects/{project_id}/locations/{region}/services/{service_id}'
+        service = f"projects/{project_id}/locations/{region}/services/{service_id}"
         backup = (
-            f'projects/{backup_project_id}/locations/{backup_region}/services/'
-            f'{backup_service_id}/backups/{backup_id}'
+            f"projects/{backup_project_id}/locations/{backup_region}/services/"
+            f"{backup_service_id}/backups/{backup_id}"
         )
 
         client = self.get_dataproc_metastore_client()
         result = client.restore_service(
             request={
-                'service': service,
-                'backup': backup,
-                'restore_type': restore_type,
-                'request_id': request_id,
+                "service": service,
+                "backup": backup,
+                "restore_type": restore_type,
+                "request_id": request_id,
             },
             retry=retry,
             timeout=timeout,
@@ -574,12 +576,12 @@ class DataprocMetastoreHook(GoogleBaseHook):
         project_id: str,
         region: str,
         service_id: str,
-        service: Union[Dict, Service],
+        service: dict | Service,
         update_mask: FieldMask,
-        request_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        request_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Updates the parameters of a single service.
@@ -613,15 +615,15 @@ class DataprocMetastoreHook(GoogleBaseHook):
         """
         client = self.get_dataproc_metastore_client()
 
-        service_name = f'projects/{project_id}/locations/{region}/services/{service_id}'
+        service_name = f"projects/{project_id}/locations/{region}/services/{service_id}"
 
         service["name"] = service_name
 
         result = client.update_service(
             request={
-                'service': service,
-                'update_mask': update_mask,
-                'request_id': request_id,
+                "service": service,
+                "update_mask": update_mask,
+                "request_id": request_id,
             },
             retry=retry,
             timeout=timeout,
