@@ -18,6 +18,7 @@
 """This module contains a Google Cloud Spanner Hook."""
 from __future__ import annotations
 
+import warnings
 from typing import Callable, Sequence
 
 from google.api_core.exceptions import AlreadyExists, GoogleAPICallError
@@ -46,6 +47,10 @@ class SpannerHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -59,7 +64,6 @@ class SpannerHook(GoogleBaseHook):
 
         :param project_id: The ID of the Google Cloud project.
         :return: Client
-        :rtype: google.cloud.spanner_v1.client.Client
         """
         if not self._client:
             self._client = Client(
@@ -81,7 +85,6 @@ class SpannerHook(GoogleBaseHook):
             is used.
         :param instance_id: The ID of the Cloud Spanner instance.
         :return: Spanner instance
-        :rtype: google.cloud.spanner_v1.instance.Instance
         """
         instance = self._get_client(project_id=project_id).instance(instance_id=instance_id)
         if not instance.exists():
@@ -117,9 +120,9 @@ class SpannerHook(GoogleBaseHook):
             display_name=display_name,
         )
         try:
-            operation = func(instance)  # type: Operation
+            operation: Operation = func(instance)
         except GoogleAPICallError as e:
-            self.log.error('An error occurred: %s. Exiting.', e.message)
+            self.log.error("An error occurred: %s. Exiting.", e.message)
             raise e
 
         if operation:
@@ -202,7 +205,7 @@ class SpannerHook(GoogleBaseHook):
             instance.delete()
             return
         except GoogleAPICallError as e:
-            self.log.error('An error occurred: %s. Exiting.', e.message)
+            self.log.error("An error occurred: %s. Exiting.", e.message)
             raise e
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -222,7 +225,6 @@ class SpannerHook(GoogleBaseHook):
             database. If set to None or missing, the default project_id from the Google Cloud connection
             is used.
         :return: Database object or None if database does not exist
-        :rtype: google.cloud.spanner_v1.database.Database or None
         """
         instance = self._get_client(project_id=project_id).instance(instance_id=instance_id)
         if not instance.exists():
@@ -257,9 +259,9 @@ class SpannerHook(GoogleBaseHook):
             raise AirflowException(f"The instance {instance_id} does not exist in project {project_id} !")
         database = instance.database(database_id=database_id, ddl_statements=ddl_statements)
         try:
-            operation = database.create()  # type: Operation
+            operation: Operation = database.create()
         except GoogleAPICallError as e:
-            self.log.error('An error occurred: %s. Exiting.', e.message)
+            self.log.error("An error occurred: %s. Exiting.", e.message)
             raise e
 
         if operation:
@@ -306,7 +308,7 @@ class SpannerHook(GoogleBaseHook):
                 )
                 return
         except GoogleAPICallError as e:
-            self.log.error('An error occurred: %s. Exiting.', e.message)
+            self.log.error("An error occurred: %s. Exiting.", e.message)
             raise e
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -320,7 +322,6 @@ class SpannerHook(GoogleBaseHook):
             database. If set to None or missing, the default project_id from the Google Cloud connection
             is used.
         :return: True if everything succeeded
-        :rtype: bool
         """
         instance = self._get_client(project_id=project_id).instance(instance_id=instance_id)
         if not instance.exists():
@@ -334,7 +335,7 @@ class SpannerHook(GoogleBaseHook):
         try:
             database.drop()
         except GoogleAPICallError as e:
-            self.log.error('An error occurred: %s. Exiting.', e.message)
+            self.log.error("An error occurred: %s. Exiting.", e.message)
             raise e
 
         return True
