@@ -26,7 +26,8 @@
 """
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Optional, Sequence
+import warnings
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.exceptions import NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -156,7 +157,7 @@ class CreateBatchPredictionJobOperator(BaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = ("region", "project_id", "impersonation_chain")
+    template_fields = ("region", "project_id", "model_name", "impersonation_chain")
     operator_extra_links = (VertexAIBatchPredictionJobLink(),)
 
     def __init__(
@@ -213,9 +214,13 @@ class CreateBatchPredictionJobOperator(BaseOperator):
         self.encryption_spec_key_name = encryption_spec_key_name
         self.sync = sync
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None  # type: Optional[BatchPredictionJobHook]
+        self.hook: BatchPredictionJobHook | None = None
 
     def execute(self, context: Context):
         self.log.info("Creating Batch prediction job")
@@ -316,6 +321,10 @@ class DeleteBatchPredictionJobOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
@@ -391,6 +400,10 @@ class GetBatchPredictionJobOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
@@ -487,6 +500,10 @@ class ListBatchPredictionJobsOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
