@@ -22,7 +22,7 @@ import time
 from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.exceptions import ServerError
-from google.cloud.dataproc_v1.types import JobStatus
+from google.cloud.dataproc_v1.types import Batch, JobStatus
 
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.dataproc import DataprocHook
@@ -109,3 +109,77 @@ class DataprocJobSensor(BaseSensorOperator):
 
         self.log.info("Waiting for job %s to complete.", self.dataproc_job_id)
         return False
+
+
+class DataprocBatchSensor(BaseSensorOperator):
+    """
+    Check for the state of batch.
+
+    :param batch_id: The Dataproc batch ID to poll. (templated)
+    :param region: Required. The Cloud Dataproc region in which to handle the request. (templated)
+    :param project_id: The ID of the google cloud project in which
+        to create the cluster. (templated)
+    :param gcp_conn_id: The connection ID to use connecting to Google Cloud Platform.
+    :param wait_timeout: How many seconds wait for job to be ready.
+    """
+
+    template_fields: Sequence[str] = ("project_id", "region", "batch_id")
+    ui_color = "#f0eee4"
+
+    def __init__(
+        self,
+        *,
+        batch_id: str,
+        region: str,
+        project_id: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        wait_timeout: int | None = None,
+        **kwargs,
+    ) -> None:
+        super().__init__(**kwargs)
+        self.batch_id = batch_id
+        self.project_id = project_id
+        self.gcp_conn_id = gcp_conn_id
+        self.region = region
+        self.wait_timeout = wait_timeout
+        self.start_sensor_time: float | None = None
+
+    def execute(self, context: Context) -> None:
+        self.start_sensor_time = time.monotonic()
+        super().execute(context)
+
+    def _duration(self):
+        return time.monotonic() - self.start_sensor_time
+
+    def poke(self, context: Context) -> bool:
+        hook = DataprocHook(gcp_conn_id=self.gcp_conn_id)
+        if self.wait_timeout:
+            try:
+                batch = hook.get_batch(batch_id=self.batch_id, region=self.region, project_id=self.project_id)
+            except ServerError as err:
+                duration = self._duration()
+                self.log.info("DURATION RUN: %f", duration)
+
+                if duration > self.wait_timeout:
+                    raise AirflowException(
+                        f"Timeout: dataproc batch {self.batch_id} is not ready after {self.wait_timeout}s"
+                    )
+                self.log.info("Retrying. Dataproc API returned server error when waiting for batch: %s", err)
+                return False
+        else:
+            batch = hook.get_batch(batch_id=self.batch_id, region=self.region, project_id=self.project_id)
+
+        state = batch.state
+        if state == Batch.State.FAILED:
+            raise AirflowException("Batch failed")
+        elif state in {
+            Batch.State.CANCELLED,
+            Batch.State.CANCELLING,
+        }:
+            raise AirflowException("Batch was cancelled.")
+        elif state == Batch.State.SUCCEEDED:
+            self.log.debug("Batch %s completed successfully.", self.batch_id)
+            return True
+
+        self.log.info("Waiting for the batch %s to complete.", self.batch_id)
+        return False
