@@ -15,7 +15,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Dict, List, Tuple
+from __future__ import annotations
+
+from typing import Any
 
 from trino.client import TrinoResult
 from trino.dbapi import Cursor as TrinoCursor
@@ -41,11 +43,11 @@ class _TrinoToGCSTrinoCursorAdapter:
 
     def __init__(self, cursor: TrinoCursor):
         self.cursor: TrinoCursor = cursor
-        self.rows: List[Any] = []
+        self.rows: list[Any] = []
         self.initialized: bool = False
 
     @property
-    def description(self) -> List[Tuple]:
+    def description(self) -> list[tuple]:
         """
         This read-only attribute is a sequence of 7-item sequences.
 
@@ -135,16 +137,15 @@ class _TrinoToGCSTrinoCursorAdapter:
             raise StopIteration()
         return result
 
-    def __iter__(self) -> "_TrinoToGCSTrinoCursorAdapter":
+    def __iter__(self) -> _TrinoToGCSTrinoCursorAdapter:
         """Return self to make cursors compatible to the iteration protocol"""
         return self
 
 
 class TrinoToGCSOperator(BaseSQLToGCSOperator):
-    """Copy data from TrinoDB to Google Cloud Storage in JSON or CSV format.
+    """Copy data from TrinoDB to Google Cloud Storage in JSON, CSV or Parquet format.
 
     :param trino_conn_id: Reference to a specific Trino hook.
-    :type trino_conn_id: str
     """
 
     ui_color = "#a0e08c"
@@ -187,7 +188,7 @@ class TrinoToGCSOperator(BaseSQLToGCSOperator):
         cursor.execute(self.sql)
         return _TrinoToGCSTrinoCursorAdapter(cursor)
 
-    def field_to_bigquery(self, field) -> Dict[str, str]:
+    def field_to_bigquery(self, field) -> dict[str, str]:
         """Convert trino field type to BigQuery field type."""
         clear_field_type = field[1].upper()
         # remove type argument e.g. DECIMAL(2, 10) => DECIMAL
@@ -196,13 +197,11 @@ class TrinoToGCSOperator(BaseSQLToGCSOperator):
 
         return {"name": field[0], "type": new_field_type}
 
-    def convert_type(self, value, schema_type):
+    def convert_type(self, value, schema_type, **kwargs):
         """
         Do nothing. Trino uses JSON on the transport layer, so types are simple.
 
         :param value: Trino column value
-        :type value: Any
         :param schema_type: BigQuery data type
-        :type schema_type: str
         """
         return value
